# Description

This example shows how to include **OpenCV** in a **PyQt5** application
using **Python 3.5**.

The application requires some sort of camera to display.

### Requirements

- FFMPEG
- Visual C++ Redistributable for Visual Studio 2015
